@@ -28,11 +28,12 @@ class TargetPreModelAnalysis:
         target = self.target
         plt.hist(target, bins=30, edgecolor='k')
         plt.figure(figsize=(10, 10))
-        plt.rcParams.update({'font.size': 12})
+        # plt.rcParams.update({'font.size': 12})
         plt.xlabel('Values')
         plt.ylabel('Counts')
         plt.title(f'Histogram of {self.target.name}')
         plt.show()
+        plt.close()
 
     def plot_barplot(self):
         target = self.target
